<script src="{{STATIC_URL}}admin/js/jquery.js"></script>
    <script src="{{STATIC_URL}}admin/js/jquery.init.js"></script>
    <script src="{{STATIC_URL}}cms/js/jquery.cms.js"></script>
    <script src="{{STATIC_URL}}pages/js/jquery.cms.pages.js"></script>
    <script src="{{STATIC_URL}}media/js/jquery.cms.media.js"></script>
