{% extends "base.html" %}
{% load news pages %}


{% block feeds %}
    <link rel="alternate" type="application/rss+xml" title="{{ pages.current.title }}" href="{% page_url pages.current 'article_feed' %}">
{% endblock %}


{% block body_class %}news{% endblock %}


{% block content_secondary %}

    {% category_list category_list %}

    {% article_date_list %}

{% endblock %}
